package logic

import (
	"GtDataStore/app/cmd/organization/internal/svc"
	"GtDataStore/app/cmd/organization/pb"
	"GtDataStore/common/xerr"
	"context"
	"github.com/pkg/errors"

	"github.com/zeromicro/go-zero/core/logx"
)

type ItemHistoryDataByTimeLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewItemHistoryDataByTimeLogic(ctx context.Context, svcCtx *svc.ServiceContext) *ItemHistoryDataByTimeLogic {
	return &ItemHistoryDataByTimeLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

func (l *ItemHistoryDataByTimeLogic) ItemHistoryDataByTime(in *pb.ItemHistoryDataByTimeReq) (*pb.ItemHistoryDataListResp, error) {
	modeList, err := l.svcCtx.ItemHistoryData.QueryHistoryDataByTime(l.ctx, in)
	if err != nil {
		return nil, errors.Wrapf(xerr.NewErrCode(xerr.DB_ERROR), "model QueryHistoryDataByTime get data err:%v", err)
	}
	dataList := make([]*pb.ItemHistoryDataList, 0)
	for _, line := range modeList {
		tmp := &pb.ItemHistoryDataList{}
		tmp.ItemName = line.ItemName
		tmp.Val = line.Val
		tmp.HTime = line.HTime.Format("2006-01-02 15:04:05")
		dataList = append(dataList, tmp)
	}

	return &pb.ItemHistoryDataListResp{List: dataList}, nil
}
